@@ -1,12 +1,8 @@
 from sven.exc import *
 from sven.backend import SvnAccess
 from sven.bzr import BzrAccess
-from pkg_resources import iter_entry_points
 from webob import Request, Response, exc
 
-import simplejson
-import mimetypes
-
 def qs(dict):
     qs = ''
     for key, value in dict.items():
@@ -24,142 +20,13 @@ def redirect(req, perm=False):
         return exc.HTTPMovedPermanently(location=path)
     return exc.HTTPTemporaryRedirect(location=path)
 
-class EditView(object):
-
-    def __init__(self, template_loader):
-        self.template_loader = template_loader
-
-    def new_default_mimetype(self, request):
-        return mimetypes.guess_type(request.path_info)[0] or 'text/html'
-
-    def post(self, request):
-        """
-        return response to a POST request
-        """
-        contents = request.POST.get('svenweb.resource_body')
-        #if contents is None:
-        #    return exc.HTTPForbidden('WTH?')
-
-        message = request.POST.get('svenweb.commit_message')
-        mimetype = request.POST.get('svenweb.mimetype')
-
-        return (contents, message, mimetype,
-                exc.HTTPSeeOther(location=request.path_info))
-
-    def match_save(self, request):
-        """
-        return a callable that takes a request and returns
-        (contents, commit_message, mimetype, webob.Response)
-        """
-        if request.method == "POST":
-            return self.post
-
-    def match_edit(self, request):
-        """
-        returns a callable that takes a (webob.Request, content, mimetype)
-        and returns a webob.Response
-        """
-        if request.method == "GET" and request.GET.get('view') == 'edit':
-            return self.form
-
-    def form(self, request, content, mimetype):
-        content = self.template_loader('edit.html', dict(body=content,
-                                                         mimetype=mimetype
-                                                         ))
-        content_type='text/html'
-        return Response(content_type=content_type, body=content)
-
-    def new(self, request):
-        mimetype = self.new_default_mimetype(request) 
-        content = self.template_loader('edit.html', dict(body='',
-                                                         mimetype=mimetype
-                                                         ))
-        return Response(content_type='text/html', body=content)
-    
-class HbmpView(object):
-
-    default = {'height': 16, 'width': 16, 
-               'pixelheight': '50px', 'pixelwidth': '50px',}
-
-    def pixelheight(self, req):
-        if req.GET.has_key('ph'):
-            return req.GET['ph']
-
-        return self.default['pixelheight']
-
-    def pixelwidth(self, req):
-        if req.GET.has_key('pw'):
-            return req.GET['pw']
-
-        return self.default['pixelwidth']
-
-    def parse(self, content):
-        rows = []
-        for line in content.split('\n'):
-            if not line.strip():
-                continue
-            row = [i.strip() for i in line.split(',')]
-            if rows:
-                assert len(row) == len(rows[-1]), "This doesn't look like a valid bitmap; the rows aren't all the same length."
-            rows.append(row)
-        return rows
-
-    def match_view(self, request, content, mimetype):
-        """
-        returns a callable that takes (request, content)
-        and returns a Response
-        """
-        if mimetype == 'text/csv+hbmp':
-            return self.render
-
-    def render(self, req, content):
-        html = """
-<table style='border: 1px solid black;
-              border-collapse: collapse;'>"""
-        data = self.parse(content)
-        for row in data:
-            html += "<tr>"
-            for item in row:
-                item = item.split('>')
-                #assert len(item) == 1 or len(item) == 2, "Bad cell format"
-                if len(item) == 2:
-                    item, link = item
-                elif len(item) == 1:
-                    item = item[0]
-                    link = None
-
-                if not link:
-                    html += """
-<td class='%s' height='%s' width='%s' 
-    style='padding: 0; border: 1px solid black; background-color: %s'>
-""" % (
-                        item,
-                        self.pixelheight(req),
-                        self.pixelwidth(req),
-                        item)
-                else:
-                    html += """
-<td href='%s' class='%s' height='%s' width='%s' 
-    style='padding: 0; border: 1px solid black; background-color: %s'>
-""" % (
-                        link,
-                        item,
-                        self.pixelheight(req),
-                        self.pixelwidth(req),
-                        item)
-                    html += "<center><a href='%s'>&nbsp;</a></center>" % link
-
-                html += "&nbsp;</td>"
-
-            html += "</tr>"
-        html += "</table>"
-        return Response(html)
 
 class SvnWikiView(object):
 
     def __init__(self, 
                  checkout_dir,
                  template_loader,
+                 editor, viewer,
                  repo_type=None,
                  ):
 
@@ -172,56 +39,13 @@ class SvnWikiView(object):
         else:
             self.backend = SvnAccess
 
-        self.editor = EditView(template_loader)
+        self.editor = editor
 
-        self.viewer = HbmpView()
+        self.viewer = viewer
 
     def svn(self, request):
         return self.backend(self.checkout_dir)
 
-    ### methods dealing with HTTP
-    def __call__(self, environ, start_response):        
-        request = Request(environ)
-        request.path_info = request.path_info.rstrip('/')
-
-        res = self.handle_request(request)
-        return res(environ, start_response)
-
-    def handle_request(self, request):
-        save = self.editor.match_save(request)
-        if save:
-            contents, message, mimetype, res = save(request)
-            
-            self.svn(request).write(request.path_info, 
-                                    contents, message, mimetype)
-
-            return res
-
-        edit = self.editor.match_edit(request)
-        if edit:
-            try:
-                q = self.svn(request).read(request.path_info)
-                content = q['body']
-                mimetype = q['mimetype']
-            except NotAFile:
-                return exc.HTTPBadRequest("Cannot edit directories")
-            except NoSuchResource:
-                return self.editor.new(request)
-            return edit(request, content, mimetype)
-
-        if request.method != "GET":
-            return exc.HTTPMethodNotAllowed("GET", "POST")
-
-        views = {'history': self.history_view,
-                 'index': self.index_view,
-                 }
-
-        for view in views:
-            if request.GET.get('view') == view:
-                return views[view](request)
-
-        return self.default_view(request)
-
     def get_response(self, template, data, content_type=None):
         #if template != 'edit.html':
         #    return Response(body=data['body'],
@@ -245,6 +69,62 @@ class SvnWikiView(object):
         res.content_length = len(res.body)
         return res
 
+
+
+    def __call__(self, environ, start_response):        
+        request = Request(environ)
+        request.path_info = request.path_info.rstrip('/')
+
+        res = self.handle_request(request)
+        return res(environ, start_response)
+
+    def maybe_save(self, request):
+        save = self.editor.match_save(request)
+        if not save:
+            return None
+
+        contents, message, mimetype, res = save(request)
+        self.svn(request).write(request.path_info, 
+                                contents, message, mimetype)
+        return res
+
+    def maybe_editform(self, request):
+        try:
+            q = self.svn(request).read(request.path_info)
+            content = q['body']
+            mimetype = q['mimetype']
+        except NotAFile:
+            return exc.HTTPBadRequest("Cannot edit directories")
+        except NoSuchResource:
+            return self.editor.new(request)
+
+        edit = self.editor.match_edit(request, content, mimetype)
+        if not edit:
+            return None
+
+        return edit(request, content, mimetype)
+
+    def handle_request(self, request):
+        if request.method == "POST":
+            save = self.maybe_save(request)
+            if save is not None: return save
+
+        if request.method == "GET" and request.GET.get('view') == 'edit':
+            edit = self.maybe_editform(request)
+            if edit is not None: return edit
+
+        if request.method != "GET":
+            return exc.HTTPMethodNotAllowed("GET", "POST")
+
+        if request.GET.get('view') == 'history':
+            return self.history_view(request)
+
+        if request.GET.get('view') == 'index':
+            return self.index_view(request)
+
+        return self.default_view(request)
+
+
     def history_view(self, request):
         version = request.GET.get('version', None)
         try:
@@ -277,7 +157,13 @@ class SvnWikiView(object):
             request.GET['version'] = str(e.last_change)
             return redirect(request, perm=True)
 
-        contents = {'globs': contents}
+        prefix = request.script_name.rstrip('/')
+
+        for item in contents:
+            item['href'] = '/'.join((prefix, item['href'].lstrip('/')))
+
+        contents = {'globs': contents,
+                    'request': request}
         contents['title'] = request.path_info.rstrip('/')
 
         # put the raw form of the resource in the wsgi environment
@@ -290,6 +176,7 @@ class SvnWikiView(object):
         version =request.GET.get('version', None)
 
         if request.path_info == '':
+            request.path_info = '/'
             request.GET['view'] = 'index'
             return redirect(request)
 
